@@ -44,8 +44,9 @@ else:
 class Willie(irc.Bot):
     NOLIMIT = module.NOLIMIT
 
-    def __init__(self, config):
+    def __init__(self, config, daemon=False):
         irc.Bot.__init__(self, config.core)
+        self._daemon = daemon
         self.config = config
         """The ``Config`` for the current Willie instance."""
         self.doc = {}
@@ -107,7 +108,7 @@ class Willie(irc.Bot):
             self.config.core.host_blocks = []
         # Add nicks blocked under old scheme, if present
         # Why the fuck is this still here? Remove for 6.0.
-        if self.config.core.other_bots:
+        if self.config.parser.has_option('core', 'other_bots'):
             nicks = self.config.core.get_list('nick_blocks')
             bots = self.config.core.get_list('other_bots')
             nicks.extend(bots)
