@@ -17,25 +17,40 @@ from __future__ import unicode_literals
 
 
 import re
+import sys
 import time
 import willie
 from willie.tools import Identifier, iteritems
 import base64
 from willie.logger import get_logger
 
+if sys.version_info.major >= 3:
+    unicode = str
+
 LOGGER = get_logger(__name__)
 
 
+def _have_conf(bot, name):
+    """Shim to prevent deprecation warnings"""
+    return bot.config.parser.has_option('core', name)
+
+
 def auth_after_register(bot):
     """Do NickServ/AuthServ auth"""
-    if bot.config.core.auth_method == 'nickserv' or bot.config.core.nickserv_password:
-        nickserv_name = bot.config.core.auth_target or bot.config.core.nickserv_name or 'NickServ'
+    if bot.config.core.auth_method == 'nickserv' or _have_conf(bot, 'nickserv_password'):
+        if bot.config.core.auth_target:
+            nickserv_name = bot.config.core.auth_target
+        elif _have_conf(bot, 'nickserv_name'):
+            nickserv_name = bot.config.core.nickserv_name
+        else:
+            nickserv_name = 'NickServ'
+        password = bot.config.core.auth_password or bot.config.core.nickserv_password
         bot.msg(
             nickserv_name,
-            'IDENTIFY %s' % bot.config.core.nickserv_password
+            'IDENTIFY %s' % password
         )
 
-    elif bot.config.core.auth_method == 'authserv' or bot.config.core.authserv_password:
+    elif bot.config.core.auth_method == 'authserv' or _have_conf(bot, 'authserv_password'):
         account = bot.config.core.auth_username or bot.config.core.authserv_account
         password = bot.config.core.auth_password or bot.config.core.authserv_password
         bot.write((
@@ -380,7 +395,7 @@ def recieve_cap_ls_reply(bot, trigger):
 
     # If we want to do SASL, we have to wait before we can send CAP END. So if
     # we are, wait on 903 (SASL successful) to send it.
-    if bot.config.core.auth_method == 'sasl' or bot.config.core.sasl_password:
+    if bot.config.core.auth_method == 'sasl' or _have_conf(bot, 'sasl_password'):
         bot.write(('CAP', 'REQ', 'sasl'))
     else:
         bot.write(('CAP', 'END'))
@@ -392,7 +407,9 @@ def recieve_cap_ack_sasl(bot):
     password = bot.config.core.auth_password or bot.config.core.sasl_password
     if not password:
         return
-    mech = bot.config.core.sasl_mechanism or 'PLAIN'
+    mech = 'PLAIN'
+    if _have_conf(bot, 'sasl_mechanism'):
+        mech = bot.config.core.sasl_mechanism
     bot.write(('AUTHENTICATE', mech))
 
 
@@ -405,7 +422,7 @@ def auth_proceed(bot, trigger):
     # Is this right?
     sasl_username = bot.config.core.auth_username or bot.config.core.sasl_username or bot.nick
     sasl_token = '\0'.join((sasl_username, sasl_username,
-                           bot.config.core.sasl_password))
+                           bot.config.core.auth_password or bot.config.core.sasl_password))
     # Spec says we do a base 64 encode on the SASL stuff
     bot.write(('AUTHENTICATE', base64.b64encode(sasl_token.encode('utf-8'))))
 
@@ -443,23 +460,23 @@ def blocks(bot, trigger):
         'huh': "I could not figure out what you wanted to do.",
     }
 
-    masks = bot.config.core.get_list('host_blocks')
-    nicks = [Identifier(nick) for nick in bot.config.core.get_list('nick_blocks')]
+    masks = set(s for s in bot.config.core.get_list('host_blocks') if s != '')
+    nicks = set(Identifier(nick)
+                for nick in bot.config.core.get_list('nick_blocks')
+                if nick != '')
     text = trigger.group().split()
 
     if len(text) == 3 and text[1] == "list":
         if text[2] == "hostmask":
-            if len(masks) > 0 and masks.count("") == 0:
-                for each in masks:
-                    if len(each) > 0:
-                        bot.say("blocked hostmask: " + each)
+            if len(masks) > 0:
+                blocked = ', '.join(unicode(mask) for mask in masks)
+                bot.say("Blocked hostmasks: {}".format(blocked))
             else:
                 bot.reply(STRINGS['nonelisted'] % ('hostmasks'))
         elif text[2] == "nick":
-            if len(nicks) > 0 and nicks.count("") == 0:
-                for each in nicks:
-                    if len(each) > 0:
-                        bot.say("blocked nick: " + each)
+            if len(nicks) > 0:
+                blocked = ', '.join(unicode(nick) for nick in nicks)
+                bot.say("Blocked nicks: {}".format(blocked))
             else:
                 bot.reply(STRINGS['nonelisted'] % ('nicks'))
         else:
@@ -467,12 +484,12 @@ def blocks(bot, trigger):
 
     elif len(text) == 4 and text[1] == "add":
         if text[2] == "nick":
-            nicks.append(text[3])
+            nicks.add(text[3])
             bot.config.core.nick_blocks = nicks
             bot.config.save()
         elif text[2] == "hostmask":
-            masks.append(text[3].lower())
-            bot.config.core.host_blocks = masks
+            masks.add(text[3].lower())
+            bot.config.core.host_blocks = list(masks)
         else:
             bot.reply(STRINGS['invalid'] % ("adding"))
             return
@@ -485,7 +502,7 @@ def blocks(bot, trigger):
                 bot.reply(STRINGS['no_nick'] % (text[3]))
                 return
             nicks.remove(Identifier(text[3]))
-            bot.config.core.nick_blocks = nicks
+            bot.config.core.nick_blocks = [unicode(n) for n in nicks]
             bot.config.save()
             bot.reply(STRINGS['success_del'] % (text[3]))
         elif text[2] == "hostmask":
@@ -494,7 +511,7 @@ def blocks(bot, trigger):
                 bot.reply(STRINGS['no_host'] % (text[3]))
                 return
             masks.remove(mask)
-            bot.config.core.host_blocks = masks
+            bot.config.core.host_blocks = [unicode(m) for m in masks]
             bot.config.save()
             bot.reply(STRINGS['success_del'] % (text[3]))
         else:
